{% extends "bee_django_mission/base.html" %}
{% load static %}
{% block content %}
    {% include 'bee_django_mission/logo.html' %}
    {% include 'bee_django_mission/nav.html' %}
    {#    <h4>修改【{{ mission.name }}】</h4>#}
    <form method="post">
        {% csrf_token %}
        {{ line.name }}
        {{ form.as_ul }}

        <input type="submit" value="提交"/>
    </form>
{% endblock %}


{% block scripts %}
    <script>
        $(document).ready(function () {

        });
    </script>
{% endblock %}